@@ -1,4 +1,4 @@
-// $Id: genres.h,v 1.5 2006/02/25 07:21:42 khlut Exp $
+// $Id: genres.h,v 1.8 2006/04/24 20:00:20 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -21,7 +21,6 @@
 #include <npupp.h>
 #include <stdio.h>
 #include <string.h>
-#include <stdio.h>
 #include <prmem.h>
 #include <prthread.h>
 #include <plevent.h>
@@ -71,6 +70,8 @@ typedef struct {
   PRThread *browser, *observer;
   pid_t slave;
   FILE *slavectrl;
+  int stream;
+  NPStream *npstream;
   Window xid;
   char *mime;
   storage *vars;
@@ -92,6 +93,9 @@ char *find_slave(char *mime);
 void wait_slave(PD * pd);
 void init_qservice(void*);
 void shut_qservice();
+char *strpath(char *_path);
+char *pair(char **s, const char *spaces, const char *delims, const char *eols);
+void configure();
 
-extern int debug;
+extern int debug, mozillastreams;
 #define Debug debug&&printf
