@@ -1,4 +1,4 @@
-// $Id: main_thread.c,v 1.17 2006/04/27 16:34:05 khlut Exp $
+// $Id: main_thread.c,v 1.18 2006/05/10 11:28:23 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -440,6 +440,8 @@ NPError NPP_Destroy (NPP instance, NPSavedData** save)
 {
     Debug("%p NPP_Destroy\n", instance->pdata);
     if(Pd) {
+      if(Pd->stream)close(Pd->stream);
+      Pd->stream=0;
       if(Pd->observer && Pd->status==Running) {
 	send_value_hex(Pd,"run", 0);
 	wait_slave(Pd);
